summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/buttons/nonkdeappbutton.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker/buttons/nonkdeappbutton.cpp')
-rw-r--r--kicker/kicker/buttons/nonkdeappbutton.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kicker/kicker/buttons/nonkdeappbutton.cpp b/kicker/kicker/buttons/nonkdeappbutton.cpp
index e91a06f37..a12e48bce 100644
--- a/kicker/kicker/buttons/nonkdeappbutton.cpp
+++ b/kicker/kicker/buttons/nonkdeappbutton.cpp
@@ -45,7 +45,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "nonkdeappbutton.moc"
// this is one of the two constructors. gets called when creating a new button
// e.g. via the "non-KDE Application" dialog, not one that was saved and then
// restored.
NonKDEAppButton::NonKDEAppButton(const TQString& name,
const TQString& description,
@@ -242,7 +242,7 @@ void NonKDEAppButton::runCommand(const TQString& execStr)
if (!result)
{
// something went wrong, so let's show an error msg to the user
- KMessageBox::error(this, i18n("Cannot execute non-KDE application."),
+ KMessageBox::error(this, i18n("Cannot execute non-TDE application."),
i18n("Kicker Error"));
return;
}
@@ -45,7 +45,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "nonkdeappbutton.moc"
// this is one of the two constructors. gets called when creating a new button
-// e.g. via the "non-KDE Application" dialog, not one that was saved and then
+// e.g. via the "non-TDE Application" dialog, not one that was saved and then
// restored.
NonKDEAppButton::NonKDEAppButton(const TQString& name,